# frozen_string_literal: true

SERVICE_NAME = 'role_management'
SERVICE_TASK = 'webserver'

require 'bundler/setup'
require_relative 'system/import'

require 'http_accept_language'

require 'role_management/graphql'

require 'sinatra/json'
require 'sinatra/custom_logger'

require 'rollbar/middleware/sinatra'
require 'cht-lib-fabric/helpers/context'
require 'cht-lib-fabric/helpers/graphql_query'
require 'cht-lib-fabric/helpers/puma_stats'
require 'cht-lib-fabric/helpers/tokens'
require 'cht-lib-fabric/helpers/web_server'
require 'cht-lib-fabric/middleware/statsd'
require 'sinatra/instrumentation'

Application.finalize!

##
# Main entry point to service.
# This is where you will define your routes and endpoints.
class WebServer < ::Sinatra::Base
  include Import[:tracer,'graphql.tracers']

  register ::Platform::Helpers::GraphQLQuery
  helpers ::Platform::Helpers::WebServer
  helpers Sinatra::CustomLogger
  register ::Platform::Helpers::Context
  register ::Platform::Helpers::Tokens
  register ::Platform::Helpers::PumaStats

  configure do
    disable :method_override
    disable :static

    set :logger, Application['logger']
    enable :logging
    set :protection, except: :session_hijacking
    set :root, File.dirname(__FILE__)

    set :cht_pod, Application[:settings].pod_name
    set :jwks_uri, Application[:settings].jwks_uri
    if Application[:settings].linkerd_dtab != ''
      set :jwks_headers, 'l5d-dtab' => Application[:settings].linkerd_dtab
    end
    if Application[:settings].developer_jwt_signing != '' ||
       (Application.env != :production &&
        Application[:settings].jwks_uri == '')
      enable :jwt_developer_key
    end
    set :wavefront, Application[:wavefront]
  end

  use ::Rollbar::Middleware::Sinatra
  use ::Rack::Deflater
  use ::Platform::Middleware::StatsD, Application['statsd']
  use ::HttpAcceptLanguage::Middleware
  register ::Sinatra::Instrumentation

  get '/' do
    "#{SERVICE_NAME} - #{SERVICE_TASK}"
  end

  graphql '/graphql', ::RoleManagement::GraphQL::Schema

  before do
    Sgtn.locale = env.http_accept_language.user_preferred_languages[0]
  end
  after do
    Sgtn.locale = nil
  end
end
